/**
 * Original work: Copyright (c) 2014 Sergey Skoblikov
 * Modified work: Copyright (c) 2015-2019 Dmitry Ivanov
 *
 * This file is a part of QEverCloud project and is distributed under the terms
 * of MIT license: https://opensource.org/licenses/MIT
 */

#ifndef QEVERCLOUDOAUTH_INFTHEADER_H
#define QEVERCLOUDOAUTH_INFTHEADER_H

#include "OAuth.h"
#include "QEverCloud.h"

#endif // QEVERCLOUDOAUTH_INFTHEADER_H
